@@ -326,6 +326,74 @@ fips = [
     "56",
 ]
 
+def update_vars(ud):
+    '''
+    Update the dictionary that defines variables
+    
+    ud - dictionary, with new variables
+    
+    The dictionary should be in the format
+       {'VariableName': ['base variable','label']
+    
+    So to add say, percent asian, you could do
+       {'PercAsian': ['(B02001_005/B01001_001)*100','Percent Asian']}
+    
+    Forgive me, does not return anything, just updates
+    a bunch of global stuff for use in other download
+    functions
+    '''
+    global lab_df
+    global tot_vars
+    global bvars
+    global evars
+    global erep
+    di.update(ud)
+    lab_df = pd.DataFrame(di.values(), columns=["Def", "Desc"])
+    lab_df["Var"] = list(di.keys())
+    lab_df = lab_df[["Var", "Def", "Desc"]].copy()
+    # getting list of all the B variables I need
+    tot_vars = lab_df["Def"].tolist()
+    combo_str = " ".join(tot_vars)
+    reg_ex = r"B\d{5}(?:H_|_)\d{3}"  # single annoying H variable!
+    bvars = list(set(re.findall(reg_ex, combo_str)))
+    evars = [b + "E" for b in bvars]
+    erep = {e: b for e, b in zip(evars, bvars)}
+
+
+def rem_vars(ul):
+    '''
+    Removes potential variables to download
+    
+    ul - list of variables to remove from di
+    
+    Example can do `rem_vars(['E_HH'])`, households
+    not used in any other functions (need to make sure
+    removal won't cause other problems down the line on
+    your own)
+    
+    Forgive me, does not return anything, just updates
+    a bunch of global stuff for use in other download
+    functions
+    '''
+    global lab_df
+    global tot_vars
+    global bvars
+    global evars
+    global erep
+    for l in ul:
+        lv = di.pop(l, None)
+    lab_df = pd.DataFrame(di.values(), columns=["Def", "Desc"])
+    lab_df["Var"] = list(di.keys())
+    lab_df = lab_df[["Var", "Def", "Desc"]].copy()
+    # getting list of all the B variables I need
+    tot_vars = lab_df["Def"].tolist()
+    combo_str = " ".join(tot_vars)
+    reg_ex = r"B\d{5}(?:H_|_)\d{3}"  # single annoying H variable!
+    bvars = list(set(re.findall(reg_ex, combo_str)))
+    evars = [b + "E" for b in bvars]
+    erep = {e: b for e, b in zip(evars, bvars)}
+
+
 ############################################################################
 
 # function to take an original dataframe with the ACS variables
@@ -335,6 +403,7 @@ fips = [
 def create_svi(df, zscore=True):
     """
     df - pandas dataframe with the E variables
+    dm - mapping dictionary for variables
     zscore - boolean, use zscores to create the themes (default True)
              if false uses percentiles
 
@@ -386,22 +455,22 @@ def create_svi(df, zscore=True):
 # Note blockgroup has some missing data
 # so not all of the themes can be computed
 
-
-def get_svi(api_key, geo, zscore=True):
+def get_svi(api_key, geo, year=2018, zscore=True):
     """
     Function to get SVI data for a given geography
 
     api_key -- string with census geo api key
     geo -- string, can either be 'zip','tract','blockgroup', or 'county'
-    states -- string for specific states fips code, default to all states
+    year -- int, year for variables you want
     zscore -- boolean, whether to calculate themes via summing z-scores
               or via summing percentile rankings
 
     returns a pandas dataframe with the SVI variables for given geo
     """
     # Set up the census api
-    # ?Future work pass in year?
-    c = Census(api_key, year=2018)
+    # year currently tested with 2017, 2018, 2019
+    # other years may get errors for variable not available
+    c = Census(api_key, year=year)
     # download the data, all subgroups within a given state
     if geo == "zip":
         # Census.ALL is just '*'
